from typing import Optional

from nacl.public import PrivateKey, PublicKey, SealedBox
from nacl.signing import SigningKey, VerifyKey, SignedMessage

from v6d0auth.config import myroot, cakey

__all__ = ('vkey', 'pkey', 'sign', 'averify', 'receive', 'encrypt_self',)

_keyfile = myroot / '.key'
if _keyfile.exists():
    _skey = SigningKey(_keyfile.read_bytes())
else:
    _skey = SigningKey.generate()
    _keyfile.write_bytes(bytes(_skey))
_skey: SigningKey
vkey: VerifyKey = _skey.verify_key
_ekey: PrivateKey = _skey.to_curve25519_private_key()
pkey: PublicKey = _ekey.public_key


def sign(data: bytes) -> SignedMessage:
    return _skey.sign(data)


def verify(data: bytes, signature: Optional[bytes] = None) -> bytes:
    return vkey.verify(data, signature)


def encrypt_self(data: bytes) -> bytes:
    return SealedBox(pkey).encrypt(data)


def receive(data: bytes) -> bytes:
    return SealedBox(_ekey).decrypt(data)


if cakey:
    akey: VerifyKey = VerifyKey(cakey)


def averify(data: bytes, signature: Optional[bytes] = None) -> bytes:
    return akey.verify(data, signature)
