import argparse
import asyncio
import json
from typing import Literal

import aiohttp

from v6d0auth import certs
from v6d0auth.config import host, port

parser = argparse.ArgumentParser()
parser.add_argument('handle', type=str)


async def main():
    handle: bytes | Literal['all'] = 'all' if args.handle == 'all' else bytes.fromhex(args.handle)
    async with aiohttp.ClientSession() as session:
        # noinspection HttpUrlsUsage
        async with session.ws_connect(f'http://{host}:{port}/approve') as ws:
            nonce = await ws.receive_bytes()
            await ws.send_bytes(certs.sign(json.dumps(['all' if handle == 'all' else handle.hex(), nonce.hex()]).encode()))
            if handle != 'all':
                print((await ws.receive_bytes()).hex())


if __name__ == '__main__':
    args = parser.parse_args()
    asyncio.run(main())
